# Raptor LabSDK

The LabSDK is a package that helps you to develop Raptor-compatible features and models directly from Python.
It's usually used inside your notebook or IDE, and allows you to build features without any further installation.

This way, you can build your features and models in Raptor, and then deploy them to the cloud later on.

### For more information, please visit [Raptor](https://raptor.ml/).
